@@ -1,5 +1,4 @@
 from peewee import SqliteDatabase
-from .model import Note, database_proxy
 
 # TODO(andre): add support for other DB types
 def _sqlite_db(cfg):
@@ -9,17 +8,17 @@ def _sqlite_db(cfg):
 TYPE_MAPPING = dict(sqlite=_sqlite_db)
 
 class DatabaseLoader:
-    def __init__(self, cfg):
+    def __init__(self, cfg, database_proxy, models):
         self._cfg = cfg
+        self._database_proxy = database_proxy
+        self._models = models
 
     def load(self):
         db_type = self._cfg['type']
         if db_type not in TYPE_MAPPING:
             raise Exception(f'db type {db_type} not supported. currently supported {TYPE_MAPPING.keys()}')
         database = TYPE_MAPPING[db_type](self._cfg)
-        database_proxy.initialize(database)
+        self._database_proxy.initialize(database)
         database.connect()
-        database.create_tables([
-            Note
-        ])
+        database.create_tables(models)
         return database
